# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/filetransfer/filetransfer.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.actions import actions_pb2 as yamcs_dot_protobuf_dot_actions_dot_actions__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/filetransfer/filetransfer.proto',
  package='yamcs.protobuf.filetransfer',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\021FileTransferProtoP\001',
  serialized_pb=b'\n.yamcs/protobuf/filetransfer/filetransfer.proto\x12\x1byamcs.protobuf.filetransfer\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1byamcs/api/annotations.proto\x1a$yamcs/protobuf/actions/actions.proto\"@\n\rTransactionId\x12\x16\n\x0esequenceNumber\x18\x01 \x01(\r\x12\x17\n\x0finitiatorEntity\x18\x02 \x01(\x04\"3\n\x1fListFileTransferServicesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"F\n\x1dGetFileTransferServiceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\"j\n ListFileTransferServicesResponse\x12\x46\n\x08services\x18\x01 \x03(\x0b\x32\x34.yamcs.protobuf.filetransfer.FileTransferServiceInfo\"\x95\x02\n\x18\x46ileTransferCapabilities\x12\x0e\n\x06upload\x18\x01 \x01(\x08\x12\x10\n\x08\x64ownload\x18\x02 \x01(\x08\x12\x12\n\nremotePath\x18\x04 \x01(\x08\x12\x10\n\x08\x66ileList\x18\x05 \x01(\x08\x12\x17\n\x0fhasTransferType\x18\x06 \x01(\x08\x12\x13\n\x0bpauseResume\x18\t \x01(\x08\x12J\n\x14\x66ileListExtraColumns\x18\x07 \x03(\x0b\x32,.yamcs.protobuf.filetransfer.ExtraColumnInfo\x12\x37\n\x0b\x66ileActions\x18\x08 \x03(\x0b\x32\".yamcs.protobuf.actions.ActionInfo\",\n\x0f\x45xtraColumnInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\"\xd1\x02\n\x17\x46ileTransferServiceInfo\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12>\n\rlocalEntities\x18\x03 \x03(\x0b\x32\'.yamcs.protobuf.filetransfer.EntityInfo\x12?\n\x0eremoteEntities\x18\x04 \x03(\x0b\x32\'.yamcs.protobuf.filetransfer.EntityInfo\x12K\n\x0c\x63\x61pabilities\x18\x05 \x01(\x0b\x32\x35.yamcs.protobuf.filetransfer.FileTransferCapabilities\x12H\n\x0ftransferOptions\x18\x06 \x03(\x0b\x32/.yamcs.protobuf.filetransfer.FileTransferOption\"&\n\nEntityInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\"\xdc\x04\n\x0cTransferInfo\x12\n\n\x02id\x18\x01 \x01(\x04\x12-\n\tstartTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x05state\x18\x03 \x01(\x0e\x32*.yamcs.protobuf.filetransfer.TransferState\x12\x0e\n\x06\x62ucket\x18\x04 \x01(\t\x12\x12\n\nobjectName\x18\x05 \x01(\t\x12\x12\n\nremotePath\x18\x06 \x01(\t\x12\x41\n\tdirection\x18\x07 \x01(\x0e\x32..yamcs.protobuf.filetransfer.TransferDirection\x12\x11\n\ttotalSize\x18\x08 \x01(\x04\x12\x17\n\x0fsizeTransferred\x18\t \x01(\x04\x12\x10\n\x08reliable\x18\n \x01(\x08\x12\x15\n\rfailureReason\x18\x0b \x01(\t\x12\x41\n\rtransactionId\x18\x0c \x01(\x0b\x32*.yamcs.protobuf.filetransfer.TransactionId\x12\x30\n\x0c\x63reationTime\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0ctransferType\x18\x0e \x01(\t\x12<\n\x0blocalEntity\x18\x0f \x01(\x0b\x32\'.yamcs.protobuf.filetransfer.EntityInfo\x12=\n\x0cremoteEntity\x18\x10 \x01(\x0b\x32\'.yamcs.protobuf.filetransfer.EntityInfo\"\x88\x02\n\x15\x43reateTransferRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x08 \x01(\t\x12\x41\n\tdirection\x18\x02 \x01(\x0e\x32..yamcs.protobuf.filetransfer.TransferDirection\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x12\n\nobjectName\x18\x04 \x01(\t\x12\x12\n\nremotePath\x18\x05 \x01(\t\x12\x0e\n\x06source\x18\t \x01(\t\x12\x13\n\x0b\x64\x65stination\x18\n \x01(\t\x12(\n\x07options\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\"I\n\x14PauseTransferRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x03 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\"J\n\x15\x43\x61ncelTransferRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x03 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\"J\n\x15ResumeTransferRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x03 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\"\xdd\x02\n\x14ListTransfersRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\x12)\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rlocalEntityId\x18\x05 \x01(\x03\x12\x16\n\x0eremoteEntityId\x18\x06 \x01(\x03\x12\x39\n\x05state\x18\x07 \x03(\x0e\x32*.yamcs.protobuf.filetransfer.TransferState\x12\x41\n\tdirection\x18\x08 \x01(\x0e\x32..yamcs.protobuf.filetransfer.TransferDirection\x12\r\n\x05limit\x18\t \x01(\x05\x12\r\n\x05order\x18\n \x01(\t\"G\n\x12GetTransferRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x03 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\"U\n\x15ListTransfersResponse\x12<\n\ttransfers\x18\x01 \x03(\x0b\x32).yamcs.protobuf.filetransfer.TransferInfo\"W\n\x19SubscribeTransfersRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\x12\x13\n\x0bongoingOnly\x18\x03 \x01(\x08\"\x9c\x01\n\x10ListFilesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65stination\x18\x04 \x01(\t\x12\x12\n\nremotePath\x18\x05 \x01(\t\x12(\n\x07options\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xa8\x01\n\nRemoteFile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64isplayName\x18\x05 \x01(\t\x12\x13\n\x0bisDirectory\x18\x02 \x01(\x08\x12\x0c\n\x04size\x18\x03 \x01(\x04\x12,\n\x08modified\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x05\x65xtra\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xca\x01\n\x11ListFilesResponse\x12\x36\n\x05\x66iles\x18\x01 \x03(\x0b\x32\'.yamcs.protobuf.filetransfer.RemoteFile\x12\x13\n\x0b\x64\x65stination\x18\x02 \x01(\t\x12\x12\n\nremotePath\x18\x03 \x01(\t\x12,\n\x08listTime\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05state\x18\x05 \x01(\t\x12\x17\n\x0fprogressMessage\x18\x06 \x01(\t\"\x9b\x01\n\x14RunFileActionRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\x12\x14\n\x0cremoteEntity\x18\x03 \x01(\t\x12\x0c\n\x04\x66ile\x18\x04 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\t\x12(\n\x07message\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xef\x02\n\x12\x46ileTransferOption\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x42\n\x04type\x18\x02 \x01(\x0e\x32\x34.yamcs.protobuf.filetransfer.FileTransferOption.Type\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x16\n\x0e\x61ssociatedText\x18\x05 \x01(\t\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x06 \x01(\t\x12\x45\n\x06values\x18\x07 \x03(\x0b\x32\x35.yamcs.protobuf.filetransfer.FileTransferOption.Value\x12\x19\n\x11\x61llowCustomOption\x18\x08 \x01(\x08\x1a+\n\x05Value\x12\r\n\x05value\x18\x01 \x01(\t\x12\x13\n\x0bverboseName\x18\x02 \x01(\t\"+\n\x04Type\x12\x0b\n\x07\x42OOLEAN\x10\x00\x12\n\n\x06\x44OUBLE\x10\x01\x12\n\n\x06STRING\x10\x02*-\n\x11TransferDirection\x12\n\n\x06UPLOAD\x10\x01\x12\x0c\n\x08\x44OWNLOAD\x10\x02*_\n\rTransferState\x12\x0b\n\x07RUNNING\x10\x01\x12\n\n\x06PAUSED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x12\n\n\x06QUEUED\x10\x05\x12\x0e\n\nCANCELLING\x10\x06\x32\xc9\x11\n\x0f\x46ileTransferApi\x12\xc4\x01\n\x18ListFileTransferServices\x12<.yamcs.protobuf.filetransfer.ListFileTransferServicesRequest\x1a=.yamcs.protobuf.filetransfer.ListFileTransferServicesResponse\"+\x8a\x92\x03\'\n%/api/filetransfer/{instance}/services\x12\xc5\x01\n\x16GetFileTransferService\x12:.yamcs.protobuf.filetransfer.GetFileTransferServiceRequest\x1a\x34.yamcs.protobuf.filetransfer.FileTransferServiceInfo\"9\x8a\x92\x03\x35\n3/api/filetransfer/{instance}/services/{serviceName}\x12\xb2\x01\n\rListTransfers\x12\x31.yamcs.protobuf.filetransfer.ListTransfersRequest\x1a\x32.yamcs.protobuf.filetransfer.ListTransfersResponse\":\x8a\x92\x03\x36\n4/api/filetransfer/{instance}/{serviceName}/transfers\x12\xaa\x01\n\x0bGetTransfer\x12/.yamcs.protobuf.filetransfer.GetTransferRequest\x1a).yamcs.protobuf.filetransfer.TransferInfo\"?\x8a\x92\x03;\n9/api/filetransfer/{instance}/{serviceName}/transfers/{id}\x12\xae\x01\n\x0e\x43reateTransfer\x12\x32.yamcs.protobuf.filetransfer.CreateTransferRequest\x1a).yamcs.protobuf.filetransfer.TransferInfo\"=\x8a\x92\x03\x39\x1a\x34/api/filetransfer/{instance}/{serviceName}/transfers:\x01*\x12\xa1\x01\n\rPauseTransfer\x12\x31.yamcs.protobuf.filetransfer.PauseTransferRequest\x1a\x16.google.protobuf.Empty\"E\x8a\x92\x03\x41\x1a?/api/filetransfer/{instance}/{serviceName}/transfers/{id}:pause\x12\xa4\x01\n\x0e\x43\x61ncelTransfer\x12\x32.yamcs.protobuf.filetransfer.CancelTransferRequest\x1a\x16.google.protobuf.Empty\"F\x8a\x92\x03\x42\x1a@/api/filetransfer/{instance}/{serviceName}/transfers/{id}:cancel\x12\xa4\x01\n\x0eResumeTransfer\x12\x32.yamcs.protobuf.filetransfer.ResumeTransferRequest\x1a\x16.google.protobuf.Empty\"F\x8a\x92\x03\x42\x1a@/api/filetransfer/{instance}/{serviceName}/transfers/{id}:resume\x12\x8f\x01\n\x12SubscribeTransfers\x12\x36.yamcs.protobuf.filetransfer.SubscribeTransfersRequest\x1a).yamcs.protobuf.filetransfer.TransferInfo\"\x14\xda\x92\x03\x10\n\x0e\x66ile-transfers0\x01\x12\x9b\x01\n\x17SubscribeRemoteFileList\x12\x36.yamcs.protobuf.filetransfer.SubscribeTransfersRequest\x1a..yamcs.protobuf.filetransfer.ListFilesResponse\"\x16\xda\x92\x03\x12\n\x10remote-file-list0\x01\x12\x96\x01\n\rFetchFileList\x12-.yamcs.protobuf.filetransfer.ListFilesRequest\x1a\x16.google.protobuf.Empty\">\x8a\x92\x03:\x1a\x35/api/filetransfer/{instance}/{serviceName}/files:sync:\x01*\x12\xab\x01\n\x0bGetFileList\x12-.yamcs.protobuf.filetransfer.ListFilesRequest\x1a..yamcs.protobuf.filetransfer.ListFilesResponse\"=\x8a\x92\x03\x39\n0/api/filetransfer/{instance}/{serviceName}/filesR\x05\x66iles\x12\xa4\x01\n\rRunFileAction\x12\x31.yamcs.protobuf.filetransfer.RunFileActionRequest\x1a\x17.google.protobuf.Struct\"G\x8a\x92\x03\x43\x1a>/api/filetransfer/{instance}/{serviceName}/files:runFileAction:\x01*\x1a\x04\xd0\x80\x01\x01\x42)\n\x12org.yamcs.protobufB\x11\x46ileTransferProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_actions_dot_actions__pb2.DESCRIPTOR,])

_TRANSFERDIRECTION = _descriptor.EnumDescriptor(
  name='TransferDirection',
  full_name='yamcs.protobuf.filetransfer.TransferDirection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UPLOAD', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOWNLOAD', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4008,
  serialized_end=4053,
)
_sym_db.RegisterEnumDescriptor(_TRANSFERDIRECTION)

TransferDirection = enum_type_wrapper.EnumTypeWrapper(_TRANSFERDIRECTION)
_TRANSFERSTATE = _descriptor.EnumDescriptor(
  name='TransferState',
  full_name='yamcs.protobuf.filetransfer.TransferState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUEUED', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELLING', index=5, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4055,
  serialized_end=4150,
)
_sym_db.RegisterEnumDescriptor(_TRANSFERSTATE)

TransferState = enum_type_wrapper.EnumTypeWrapper(_TRANSFERSTATE)
UPLOAD = 1
DOWNLOAD = 2
RUNNING = 1
PAUSED = 2
FAILED = 3
COMPLETED = 4
QUEUED = 5
CANCELLING = 6


_FILETRANSFEROPTION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.filetransfer.FileTransferOption.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3963,
  serialized_end=4006,
)
_sym_db.RegisterEnumDescriptor(_FILETRANSFEROPTION_TYPE)


_TRANSACTIONID = _descriptor.Descriptor(
  name='TransactionId',
  full_name='yamcs.protobuf.filetransfer.TransactionId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.filetransfer.TransactionId.sequenceNumber', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initiatorEntity', full_name='yamcs.protobuf.filetransfer.TransactionId.initiatorEntity', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=302,
)


_LISTFILETRANSFERSERVICESREQUEST = _descriptor.Descriptor(
  name='ListFileTransferServicesRequest',
  full_name='yamcs.protobuf.filetransfer.ListFileTransferServicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.ListFileTransferServicesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=355,
)


_GETFILETRANSFERSERVICEREQUEST = _descriptor.Descriptor(
  name='GetFileTransferServiceRequest',
  full_name='yamcs.protobuf.filetransfer.GetFileTransferServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.GetFileTransferServiceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.GetFileTransferServiceRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=427,
)


_LISTFILETRANSFERSERVICESRESPONSE = _descriptor.Descriptor(
  name='ListFileTransferServicesResponse',
  full_name='yamcs.protobuf.filetransfer.ListFileTransferServicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='services', full_name='yamcs.protobuf.filetransfer.ListFileTransferServicesResponse.services', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=429,
  serialized_end=535,
)


_FILETRANSFERCAPABILITIES = _descriptor.Descriptor(
  name='FileTransferCapabilities',
  full_name='yamcs.protobuf.filetransfer.FileTransferCapabilities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload', full_name='yamcs.protobuf.filetransfer.FileTransferCapabilities.upload', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='download', full_name='yamcs.protobuf.filetransfer.FileTransferCapabilities.download', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remotePath', full_name='yamcs.protobuf.filetransfer.FileTransferCapabilities.remotePath', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileList', full_name='yamcs.protobuf.filetransfer.FileTransferCapabilities.fileList', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasTransferType', full_name='yamcs.protobuf.filetransfer.FileTransferCapabilities.hasTransferType', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pauseResume', full_name='yamcs.protobuf.filetransfer.FileTransferCapabilities.pauseResume', index=5,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileListExtraColumns', full_name='yamcs.protobuf.filetransfer.FileTransferCapabilities.fileListExtraColumns', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileActions', full_name='yamcs.protobuf.filetransfer.FileTransferCapabilities.fileActions', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=538,
  serialized_end=815,
)


_EXTRACOLUMNINFO = _descriptor.Descriptor(
  name='ExtraColumnInfo',
  full_name='yamcs.protobuf.filetransfer.ExtraColumnInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.filetransfer.ExtraColumnInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='yamcs.protobuf.filetransfer.ExtraColumnInfo.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=817,
  serialized_end=861,
)


_FILETRANSFERSERVICEINFO = _descriptor.Descriptor(
  name='FileTransferServiceInfo',
  full_name='yamcs.protobuf.filetransfer.FileTransferServiceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.FileTransferServiceInfo.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.filetransfer.FileTransferServiceInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localEntities', full_name='yamcs.protobuf.filetransfer.FileTransferServiceInfo.localEntities', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remoteEntities', full_name='yamcs.protobuf.filetransfer.FileTransferServiceInfo.remoteEntities', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capabilities', full_name='yamcs.protobuf.filetransfer.FileTransferServiceInfo.capabilities', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transferOptions', full_name='yamcs.protobuf.filetransfer.FileTransferServiceInfo.transferOptions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=864,
  serialized_end=1201,
)


_ENTITYINFO = _descriptor.Descriptor(
  name='EntityInfo',
  full_name='yamcs.protobuf.filetransfer.EntityInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.filetransfer.EntityInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.filetransfer.EntityInfo.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1203,
  serialized_end=1241,
)


_TRANSFERINFO = _descriptor.Descriptor(
  name='TransferInfo',
  full_name='yamcs.protobuf.filetransfer.TransferInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.filetransfer.TransferInfo.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='yamcs.protobuf.filetransfer.TransferInfo.startTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.filetransfer.TransferInfo.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='yamcs.protobuf.filetransfer.TransferInfo.bucket', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectName', full_name='yamcs.protobuf.filetransfer.TransferInfo.objectName', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remotePath', full_name='yamcs.protobuf.filetransfer.TransferInfo.remotePath', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='yamcs.protobuf.filetransfer.TransferInfo.direction', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.filetransfer.TransferInfo.totalSize', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeTransferred', full_name='yamcs.protobuf.filetransfer.TransferInfo.sizeTransferred', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reliable', full_name='yamcs.protobuf.filetransfer.TransferInfo.reliable', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureReason', full_name='yamcs.protobuf.filetransfer.TransferInfo.failureReason', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactionId', full_name='yamcs.protobuf.filetransfer.TransferInfo.transactionId', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creationTime', full_name='yamcs.protobuf.filetransfer.TransferInfo.creationTime', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transferType', full_name='yamcs.protobuf.filetransfer.TransferInfo.transferType', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localEntity', full_name='yamcs.protobuf.filetransfer.TransferInfo.localEntity', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remoteEntity', full_name='yamcs.protobuf.filetransfer.TransferInfo.remoteEntity', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1244,
  serialized_end=1848,
)


_CREATETRANSFERREQUEST = _descriptor.Descriptor(
  name='CreateTransferRequest',
  full_name='yamcs.protobuf.filetransfer.CreateTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.serviceName', index=1,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.direction', index=2,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.bucket', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectName', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.objectName', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remotePath', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.remotePath', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.source', index=6,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.destination', index=7,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.options', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1851,
  serialized_end=2115,
)


_PAUSETRANSFERREQUEST = _descriptor.Descriptor(
  name='PauseTransferRequest',
  full_name='yamcs.protobuf.filetransfer.PauseTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.PauseTransferRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.PauseTransferRequest.serviceName', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.filetransfer.PauseTransferRequest.id', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2117,
  serialized_end=2190,
)


_CANCELTRANSFERREQUEST = _descriptor.Descriptor(
  name='CancelTransferRequest',
  full_name='yamcs.protobuf.filetransfer.CancelTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.CancelTransferRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.CancelTransferRequest.serviceName', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.filetransfer.CancelTransferRequest.id', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2192,
  serialized_end=2266,
)


_RESUMETRANSFERREQUEST = _descriptor.Descriptor(
  name='ResumeTransferRequest',
  full_name='yamcs.protobuf.filetransfer.ResumeTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.ResumeTransferRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.ResumeTransferRequest.serviceName', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.filetransfer.ResumeTransferRequest.id', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2268,
  serialized_end=2342,
)


_LISTTRANSFERSREQUEST = _descriptor.Descriptor(
  name='ListTransfersRequest',
  full_name='yamcs.protobuf.filetransfer.ListTransfersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.ListTransfersRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.ListTransfersRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.filetransfer.ListTransfersRequest.start', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.filetransfer.ListTransfersRequest.stop', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localEntityId', full_name='yamcs.protobuf.filetransfer.ListTransfersRequest.localEntityId', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remoteEntityId', full_name='yamcs.protobuf.filetransfer.ListTransfersRequest.remoteEntityId', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.filetransfer.ListTransfersRequest.state', index=6,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='yamcs.protobuf.filetransfer.ListTransfersRequest.direction', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.filetransfer.ListTransfersRequest.limit', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.filetransfer.ListTransfersRequest.order', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2345,
  serialized_end=2694,
)


_GETTRANSFERREQUEST = _descriptor.Descriptor(
  name='GetTransferRequest',
  full_name='yamcs.protobuf.filetransfer.GetTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.GetTransferRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.GetTransferRequest.serviceName', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.filetransfer.GetTransferRequest.id', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2696,
  serialized_end=2767,
)


_LISTTRANSFERSRESPONSE = _descriptor.Descriptor(
  name='ListTransfersResponse',
  full_name='yamcs.protobuf.filetransfer.ListTransfersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfers', full_name='yamcs.protobuf.filetransfer.ListTransfersResponse.transfers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2769,
  serialized_end=2854,
)


_SUBSCRIBETRANSFERSREQUEST = _descriptor.Descriptor(
  name='SubscribeTransfersRequest',
  full_name='yamcs.protobuf.filetransfer.SubscribeTransfersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.SubscribeTransfersRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.SubscribeTransfersRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ongoingOnly', full_name='yamcs.protobuf.filetransfer.SubscribeTransfersRequest.ongoingOnly', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2856,
  serialized_end=2943,
)


_LISTFILESREQUEST = _descriptor.Descriptor(
  name='ListFilesRequest',
  full_name='yamcs.protobuf.filetransfer.ListFilesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.ListFilesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.ListFilesRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.filetransfer.ListFilesRequest.source', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination', full_name='yamcs.protobuf.filetransfer.ListFilesRequest.destination', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remotePath', full_name='yamcs.protobuf.filetransfer.ListFilesRequest.remotePath', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='yamcs.protobuf.filetransfer.ListFilesRequest.options', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2946,
  serialized_end=3102,
)


_REMOTEFILE = _descriptor.Descriptor(
  name='RemoteFile',
  full_name='yamcs.protobuf.filetransfer.RemoteFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.filetransfer.RemoteFile.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayName', full_name='yamcs.protobuf.filetransfer.RemoteFile.displayName', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isDirectory', full_name='yamcs.protobuf.filetransfer.RemoteFile.isDirectory', index=2,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='yamcs.protobuf.filetransfer.RemoteFile.size', index=3,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modified', full_name='yamcs.protobuf.filetransfer.RemoteFile.modified', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra', full_name='yamcs.protobuf.filetransfer.RemoteFile.extra', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3105,
  serialized_end=3273,
)


_LISTFILESRESPONSE = _descriptor.Descriptor(
  name='ListFilesResponse',
  full_name='yamcs.protobuf.filetransfer.ListFilesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='yamcs.protobuf.filetransfer.ListFilesResponse.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination', full_name='yamcs.protobuf.filetransfer.ListFilesResponse.destination', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remotePath', full_name='yamcs.protobuf.filetransfer.ListFilesResponse.remotePath', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='listTime', full_name='yamcs.protobuf.filetransfer.ListFilesResponse.listTime', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.filetransfer.ListFilesResponse.state', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='progressMessage', full_name='yamcs.protobuf.filetransfer.ListFilesResponse.progressMessage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3276,
  serialized_end=3478,
)


_RUNFILEACTIONREQUEST = _descriptor.Descriptor(
  name='RunFileActionRequest',
  full_name='yamcs.protobuf.filetransfer.RunFileActionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.RunFileActionRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.RunFileActionRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remoteEntity', full_name='yamcs.protobuf.filetransfer.RunFileActionRequest.remoteEntity', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file', full_name='yamcs.protobuf.filetransfer.RunFileActionRequest.file', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='yamcs.protobuf.filetransfer.RunFileActionRequest.action', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='yamcs.protobuf.filetransfer.RunFileActionRequest.message', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3481,
  serialized_end=3636,
)


_FILETRANSFEROPTION_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='yamcs.protobuf.filetransfer.FileTransferOption.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.filetransfer.FileTransferOption.Value.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='verboseName', full_name='yamcs.protobuf.filetransfer.FileTransferOption.Value.verboseName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3918,
  serialized_end=3961,
)

_FILETRANSFEROPTION = _descriptor.Descriptor(
  name='FileTransferOption',
  full_name='yamcs.protobuf.filetransfer.FileTransferOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.filetransfer.FileTransferOption.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.filetransfer.FileTransferOption.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='yamcs.protobuf.filetransfer.FileTransferOption.title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.filetransfer.FileTransferOption.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='associatedText', full_name='yamcs.protobuf.filetransfer.FileTransferOption.associatedText', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default', full_name='yamcs.protobuf.filetransfer.FileTransferOption.default', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='yamcs.protobuf.filetransfer.FileTransferOption.values', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allowCustomOption', full_name='yamcs.protobuf.filetransfer.FileTransferOption.allowCustomOption', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FILETRANSFEROPTION_VALUE, ],
  enum_types=[
    _FILETRANSFEROPTION_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3639,
  serialized_end=4006,
)

_LISTFILETRANSFERSERVICESRESPONSE.fields_by_name['services'].message_type = _FILETRANSFERSERVICEINFO
_FILETRANSFERCAPABILITIES.fields_by_name['fileListExtraColumns'].message_type = _EXTRACOLUMNINFO
_FILETRANSFERCAPABILITIES.fields_by_name['fileActions'].message_type = yamcs_dot_protobuf_dot_actions_dot_actions__pb2._ACTIONINFO
_FILETRANSFERSERVICEINFO.fields_by_name['localEntities'].message_type = _ENTITYINFO
_FILETRANSFERSERVICEINFO.fields_by_name['remoteEntities'].message_type = _ENTITYINFO
_FILETRANSFERSERVICEINFO.fields_by_name['capabilities'].message_type = _FILETRANSFERCAPABILITIES
_FILETRANSFERSERVICEINFO.fields_by_name['transferOptions'].message_type = _FILETRANSFEROPTION
_TRANSFERINFO.fields_by_name['startTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSFERINFO.fields_by_name['state'].enum_type = _TRANSFERSTATE
_TRANSFERINFO.fields_by_name['direction'].enum_type = _TRANSFERDIRECTION
_TRANSFERINFO.fields_by_name['transactionId'].message_type = _TRANSACTIONID
_TRANSFERINFO.fields_by_name['creationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSFERINFO.fields_by_name['localEntity'].message_type = _ENTITYINFO
_TRANSFERINFO.fields_by_name['remoteEntity'].message_type = _ENTITYINFO
_CREATETRANSFERREQUEST.fields_by_name['direction'].enum_type = _TRANSFERDIRECTION
_CREATETRANSFERREQUEST.fields_by_name['options'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_LISTTRANSFERSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTTRANSFERSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTTRANSFERSREQUEST.fields_by_name['state'].enum_type = _TRANSFERSTATE
_LISTTRANSFERSREQUEST.fields_by_name['direction'].enum_type = _TRANSFERDIRECTION
_LISTTRANSFERSRESPONSE.fields_by_name['transfers'].message_type = _TRANSFERINFO
_LISTFILESREQUEST.fields_by_name['options'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_REMOTEFILE.fields_by_name['modified'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REMOTEFILE.fields_by_name['extra'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_LISTFILESRESPONSE.fields_by_name['files'].message_type = _REMOTEFILE
_LISTFILESRESPONSE.fields_by_name['listTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RUNFILEACTIONREQUEST.fields_by_name['message'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_FILETRANSFEROPTION_VALUE.containing_type = _FILETRANSFEROPTION
_FILETRANSFEROPTION.fields_by_name['type'].enum_type = _FILETRANSFEROPTION_TYPE
_FILETRANSFEROPTION.fields_by_name['values'].message_type = _FILETRANSFEROPTION_VALUE
_FILETRANSFEROPTION_TYPE.containing_type = _FILETRANSFEROPTION
DESCRIPTOR.message_types_by_name['TransactionId'] = _TRANSACTIONID
DESCRIPTOR.message_types_by_name['ListFileTransferServicesRequest'] = _LISTFILETRANSFERSERVICESREQUEST
DESCRIPTOR.message_types_by_name['GetFileTransferServiceRequest'] = _GETFILETRANSFERSERVICEREQUEST
DESCRIPTOR.message_types_by_name['ListFileTransferServicesResponse'] = _LISTFILETRANSFERSERVICESRESPONSE
DESCRIPTOR.message_types_by_name['FileTransferCapabilities'] = _FILETRANSFERCAPABILITIES
DESCRIPTOR.message_types_by_name['ExtraColumnInfo'] = _EXTRACOLUMNINFO
DESCRIPTOR.message_types_by_name['FileTransferServiceInfo'] = _FILETRANSFERSERVICEINFO
DESCRIPTOR.message_types_by_name['EntityInfo'] = _ENTITYINFO
DESCRIPTOR.message_types_by_name['TransferInfo'] = _TRANSFERINFO
DESCRIPTOR.message_types_by_name['CreateTransferRequest'] = _CREATETRANSFERREQUEST
DESCRIPTOR.message_types_by_name['PauseTransferRequest'] = _PAUSETRANSFERREQUEST
DESCRIPTOR.message_types_by_name['CancelTransferRequest'] = _CANCELTRANSFERREQUEST
DESCRIPTOR.message_types_by_name['ResumeTransferRequest'] = _RESUMETRANSFERREQUEST
DESCRIPTOR.message_types_by_name['ListTransfersRequest'] = _LISTTRANSFERSREQUEST
DESCRIPTOR.message_types_by_name['GetTransferRequest'] = _GETTRANSFERREQUEST
DESCRIPTOR.message_types_by_name['ListTransfersResponse'] = _LISTTRANSFERSRESPONSE
DESCRIPTOR.message_types_by_name['SubscribeTransfersRequest'] = _SUBSCRIBETRANSFERSREQUEST
DESCRIPTOR.message_types_by_name['ListFilesRequest'] = _LISTFILESREQUEST
DESCRIPTOR.message_types_by_name['RemoteFile'] = _REMOTEFILE
DESCRIPTOR.message_types_by_name['ListFilesResponse'] = _LISTFILESRESPONSE
DESCRIPTOR.message_types_by_name['RunFileActionRequest'] = _RUNFILEACTIONREQUEST
DESCRIPTOR.message_types_by_name['FileTransferOption'] = _FILETRANSFEROPTION
DESCRIPTOR.enum_types_by_name['TransferDirection'] = _TRANSFERDIRECTION
DESCRIPTOR.enum_types_by_name['TransferState'] = _TRANSFERSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TransactionId = _reflection.GeneratedProtocolMessageType('TransactionId', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONID,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.TransactionId)
  })
_sym_db.RegisterMessage(TransactionId)

ListFileTransferServicesRequest = _reflection.GeneratedProtocolMessageType('ListFileTransferServicesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFILETRANSFERSERVICESREQUEST,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.ListFileTransferServicesRequest)
  })
_sym_db.RegisterMessage(ListFileTransferServicesRequest)

GetFileTransferServiceRequest = _reflection.GeneratedProtocolMessageType('GetFileTransferServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFILETRANSFERSERVICEREQUEST,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.GetFileTransferServiceRequest)
  })
_sym_db.RegisterMessage(GetFileTransferServiceRequest)

ListFileTransferServicesResponse = _reflection.GeneratedProtocolMessageType('ListFileTransferServicesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFILETRANSFERSERVICESRESPONSE,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.ListFileTransferServicesResponse)
  })
_sym_db.RegisterMessage(ListFileTransferServicesResponse)

FileTransferCapabilities = _reflection.GeneratedProtocolMessageType('FileTransferCapabilities', (_message.Message,), {
  'DESCRIPTOR' : _FILETRANSFERCAPABILITIES,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.FileTransferCapabilities)
  })
_sym_db.RegisterMessage(FileTransferCapabilities)

ExtraColumnInfo = _reflection.GeneratedProtocolMessageType('ExtraColumnInfo', (_message.Message,), {
  'DESCRIPTOR' : _EXTRACOLUMNINFO,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.ExtraColumnInfo)
  })
_sym_db.RegisterMessage(ExtraColumnInfo)

FileTransferServiceInfo = _reflection.GeneratedProtocolMessageType('FileTransferServiceInfo', (_message.Message,), {
  'DESCRIPTOR' : _FILETRANSFERSERVICEINFO,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.FileTransferServiceInfo)
  })
_sym_db.RegisterMessage(FileTransferServiceInfo)

EntityInfo = _reflection.GeneratedProtocolMessageType('EntityInfo', (_message.Message,), {
  'DESCRIPTOR' : _ENTITYINFO,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.EntityInfo)
  })
_sym_db.RegisterMessage(EntityInfo)

TransferInfo = _reflection.GeneratedProtocolMessageType('TransferInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERINFO,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.TransferInfo)
  })
_sym_db.RegisterMessage(TransferInfo)

CreateTransferRequest = _reflection.GeneratedProtocolMessageType('CreateTransferRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETRANSFERREQUEST,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.CreateTransferRequest)
  })
_sym_db.RegisterMessage(CreateTransferRequest)

PauseTransferRequest = _reflection.GeneratedProtocolMessageType('PauseTransferRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSETRANSFERREQUEST,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.PauseTransferRequest)
  })
_sym_db.RegisterMessage(PauseTransferRequest)

CancelTransferRequest = _reflection.GeneratedProtocolMessageType('CancelTransferRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELTRANSFERREQUEST,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.CancelTransferRequest)
  })
_sym_db.RegisterMessage(CancelTransferRequest)

ResumeTransferRequest = _reflection.GeneratedProtocolMessageType('ResumeTransferRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMETRANSFERREQUEST,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.ResumeTransferRequest)
  })
_sym_db.RegisterMessage(ResumeTransferRequest)

ListTransfersRequest = _reflection.GeneratedProtocolMessageType('ListTransfersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRANSFERSREQUEST,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.ListTransfersRequest)
  })
_sym_db.RegisterMessage(ListTransfersRequest)

GetTransferRequest = _reflection.GeneratedProtocolMessageType('GetTransferRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSFERREQUEST,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.GetTransferRequest)
  })
_sym_db.RegisterMessage(GetTransferRequest)

ListTransfersResponse = _reflection.GeneratedProtocolMessageType('ListTransfersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRANSFERSRESPONSE,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.ListTransfersResponse)
  })
_sym_db.RegisterMessage(ListTransfersResponse)

SubscribeTransfersRequest = _reflection.GeneratedProtocolMessageType('SubscribeTransfersRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBETRANSFERSREQUEST,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.SubscribeTransfersRequest)
  })
_sym_db.RegisterMessage(SubscribeTransfersRequest)

ListFilesRequest = _reflection.GeneratedProtocolMessageType('ListFilesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFILESREQUEST,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.ListFilesRequest)
  })
_sym_db.RegisterMessage(ListFilesRequest)

RemoteFile = _reflection.GeneratedProtocolMessageType('RemoteFile', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEFILE,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.RemoteFile)
  })
_sym_db.RegisterMessage(RemoteFile)

ListFilesResponse = _reflection.GeneratedProtocolMessageType('ListFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFILESRESPONSE,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.ListFilesResponse)
  })
_sym_db.RegisterMessage(ListFilesResponse)

RunFileActionRequest = _reflection.GeneratedProtocolMessageType('RunFileActionRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNFILEACTIONREQUEST,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.RunFileActionRequest)
  })
_sym_db.RegisterMessage(RunFileActionRequest)

FileTransferOption = _reflection.GeneratedProtocolMessageType('FileTransferOption', (_message.Message,), {

  'Value' : _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
    'DESCRIPTOR' : _FILETRANSFEROPTION_VALUE,
    '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.FileTransferOption.Value)
    })
  ,
  'DESCRIPTOR' : _FILETRANSFEROPTION,
  '__module__' : 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.FileTransferOption)
  })
_sym_db.RegisterMessage(FileTransferOption)
_sym_db.RegisterMessage(FileTransferOption.Value)


DESCRIPTOR._options = None

_FILETRANSFERAPI = _descriptor.ServiceDescriptor(
  name='FileTransferApi',
  full_name='yamcs.protobuf.filetransfer.FileTransferApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=4153,
  serialized_end=6402,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListFileTransferServices',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.ListFileTransferServices',
    index=0,
    containing_service=None,
    input_type=_LISTFILETRANSFERSERVICESREQUEST,
    output_type=_LISTFILETRANSFERSERVICESRESPONSE,
    serialized_options=b'\212\222\003\'\n%/api/filetransfer/{instance}/services',
  ),
  _descriptor.MethodDescriptor(
    name='GetFileTransferService',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.GetFileTransferService',
    index=1,
    containing_service=None,
    input_type=_GETFILETRANSFERSERVICEREQUEST,
    output_type=_FILETRANSFERSERVICEINFO,
    serialized_options=b'\212\222\0035\n3/api/filetransfer/{instance}/services/{serviceName}',
  ),
  _descriptor.MethodDescriptor(
    name='ListTransfers',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.ListTransfers',
    index=2,
    containing_service=None,
    input_type=_LISTTRANSFERSREQUEST,
    output_type=_LISTTRANSFERSRESPONSE,
    serialized_options=b'\212\222\0036\n4/api/filetransfer/{instance}/{serviceName}/transfers',
  ),
  _descriptor.MethodDescriptor(
    name='GetTransfer',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.GetTransfer',
    index=3,
    containing_service=None,
    input_type=_GETTRANSFERREQUEST,
    output_type=_TRANSFERINFO,
    serialized_options=b'\212\222\003;\n9/api/filetransfer/{instance}/{serviceName}/transfers/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='CreateTransfer',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.CreateTransfer',
    index=4,
    containing_service=None,
    input_type=_CREATETRANSFERREQUEST,
    output_type=_TRANSFERINFO,
    serialized_options=b'\212\222\0039\0324/api/filetransfer/{instance}/{serviceName}/transfers:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='PauseTransfer',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.PauseTransfer',
    index=5,
    containing_service=None,
    input_type=_PAUSETRANSFERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003A\032?/api/filetransfer/{instance}/{serviceName}/transfers/{id}:pause',
  ),
  _descriptor.MethodDescriptor(
    name='CancelTransfer',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.CancelTransfer',
    index=6,
    containing_service=None,
    input_type=_CANCELTRANSFERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003B\032@/api/filetransfer/{instance}/{serviceName}/transfers/{id}:cancel',
  ),
  _descriptor.MethodDescriptor(
    name='ResumeTransfer',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.ResumeTransfer',
    index=7,
    containing_service=None,
    input_type=_RESUMETRANSFERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003B\032@/api/filetransfer/{instance}/{serviceName}/transfers/{id}:resume',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeTransfers',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.SubscribeTransfers',
    index=8,
    containing_service=None,
    input_type=_SUBSCRIBETRANSFERSREQUEST,
    output_type=_TRANSFERINFO,
    serialized_options=b'\332\222\003\020\n\016file-transfers',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeRemoteFileList',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.SubscribeRemoteFileList',
    index=9,
    containing_service=None,
    input_type=_SUBSCRIBETRANSFERSREQUEST,
    output_type=_LISTFILESRESPONSE,
    serialized_options=b'\332\222\003\022\n\020remote-file-list',
  ),
  _descriptor.MethodDescriptor(
    name='FetchFileList',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.FetchFileList',
    index=10,
    containing_service=None,
    input_type=_LISTFILESREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003:\0325/api/filetransfer/{instance}/{serviceName}/files:sync:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='GetFileList',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.GetFileList',
    index=11,
    containing_service=None,
    input_type=_LISTFILESREQUEST,
    output_type=_LISTFILESRESPONSE,
    serialized_options=b'\212\222\0039\n0/api/filetransfer/{instance}/{serviceName}/filesR\005files',
  ),
  _descriptor.MethodDescriptor(
    name='RunFileAction',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.RunFileAction',
    index=12,
    containing_service=None,
    input_type=_RUNFILEACTIONREQUEST,
    output_type=google_dot_protobuf_dot_struct__pb2._STRUCT,
    serialized_options=b'\212\222\003C\032>/api/filetransfer/{instance}/{serviceName}/files:runFileAction:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_FILETRANSFERAPI)

DESCRIPTOR.services_by_name['FileTransferApi'] = _FILETRANSFERAPI

# @@protoc_insertion_point(module_scope)



import warnings

warnings.warn(
    "The module 'yamcs.tco.model' is deprecated. "
    "Import classes from 'yamcs.client' instead.",
    DeprecationWarning,
    stacklevel=2,
)

from yamcs.client.tco.model import (  # noqa
    TCOCoefficients,
    TCOSample,
    TCOStatus,
    TofInterval,
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/database/database_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/database/database_service.proto',
  package='yamcs.protobuf.archive',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\016DbServiceProtoP\001',
  serialized_pb=b'\n.yamcs/protobuf/database/database_service.proto\x12\x16yamcs.protobuf.archive\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\"P\n\x15ListDatabasesResponse\x12\x37\n\tdatabases\x18\x01 \x03(\x0b\x32$.yamcs.protobuf.archive.DatabaseInfo\"\"\n\x12GetDatabaseRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"_\n\x0c\x44\x61tabaseInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x12\n\ntablespace\x18\x03 \x01(\t\x12\x0e\n\x06tables\x18\x04 \x03(\t\x12\x0f\n\x07streams\x18\x05 \x03(\t2\xff\x01\n\x0b\x44\x61tabaseApi\x12l\n\rListDatabases\x12\x16.google.protobuf.Empty\x1a-.yamcs.protobuf.archive.ListDatabasesResponse\"\x14\x8a\x92\x03\x10\n\x0e/api/databases\x12|\n\x0bGetDatabase\x12*.yamcs.protobuf.archive.GetDatabaseRequest\x1a$.yamcs.protobuf.archive.DatabaseInfo\"\x1b\x8a\x92\x03\x17\n\x15/api/databases/{name}\x1a\x04\xd0\x80\x01\x01\x42&\n\x12org.yamcs.protobufB\x0e\x44\x62ServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_LISTDATABASESRESPONSE = _descriptor.Descriptor(
  name='ListDatabasesResponse',
  full_name='yamcs.protobuf.archive.ListDatabasesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='databases', full_name='yamcs.protobuf.archive.ListDatabasesResponse.databases', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=212,
)


_GETDATABASEREQUEST = _descriptor.Descriptor(
  name='GetDatabaseRequest',
  full_name='yamcs.protobuf.archive.GetDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.GetDatabaseRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=248,
)


_DATABASEINFO = _descriptor.Descriptor(
  name='DatabaseInfo',
  full_name='yamcs.protobuf.archive.DatabaseInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.DatabaseInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='yamcs.protobuf.archive.DatabaseInfo.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tablespace', full_name='yamcs.protobuf.archive.DatabaseInfo.tablespace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tables', full_name='yamcs.protobuf.archive.DatabaseInfo.tables', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streams', full_name='yamcs.protobuf.archive.DatabaseInfo.streams', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=345,
)

_LISTDATABASESRESPONSE.fields_by_name['databases'].message_type = _DATABASEINFO
DESCRIPTOR.message_types_by_name['ListDatabasesResponse'] = _LISTDATABASESRESPONSE
DESCRIPTOR.message_types_by_name['GetDatabaseRequest'] = _GETDATABASEREQUEST
DESCRIPTOR.message_types_by_name['DatabaseInfo'] = _DATABASEINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListDatabasesResponse = _reflection.GeneratedProtocolMessageType('ListDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESRESPONSE,
  '__module__' : 'yamcs.protobuf.database.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListDatabasesResponse)
  })
_sym_db.RegisterMessage(ListDatabasesResponse)

GetDatabaseRequest = _reflection.GeneratedProtocolMessageType('GetDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASEREQUEST,
  '__module__' : 'yamcs.protobuf.database.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.GetDatabaseRequest)
  })
_sym_db.RegisterMessage(GetDatabaseRequest)

DatabaseInfo = _reflection.GeneratedProtocolMessageType('DatabaseInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATABASEINFO,
  '__module__' : 'yamcs.protobuf.database.database_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.DatabaseInfo)
  })
_sym_db.RegisterMessage(DatabaseInfo)


DESCRIPTOR._options = None

_DATABASEAPI = _descriptor.ServiceDescriptor(
  name='DatabaseApi',
  full_name='yamcs.protobuf.archive.DatabaseApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=348,
  serialized_end=603,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListDatabases',
    full_name='yamcs.protobuf.archive.DatabaseApi.ListDatabases',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTDATABASESRESPONSE,
    serialized_options=b'\212\222\003\020\n\016/api/databases',
  ),
  _descriptor.MethodDescriptor(
    name='GetDatabase',
    full_name='yamcs.protobuf.archive.DatabaseApi.GetDatabase',
    index=1,
    containing_service=None,
    input_type=_GETDATABASEREQUEST,
    output_type=_DATABASEINFO,
    serialized_options=b'\212\222\003\027\n\025/api/databases/{name}',
  ),
])
_sym_db.RegisterServiceDescriptor(_DATABASEAPI)

DESCRIPTOR.services_by_name['DatabaseApi'] = _DATABASEAPI

# @@protoc_insertion_point(module_scope)
